# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, ... }:

{
  imports =
    [ # Include the results of the hardware scan.
      ./hardware-configuration.nix
    ];

  # Bootloader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  boot.initrd.luks.devices."luks-7760761b-f1b9-4e33-b26a-88643d06d2e7".device = "/dev/disk/by-uuid/7760761b-f1b9-4e33-b26a-88643d06d2e7";
  networking.hostName = "bua69"; # Define your hostname.
  # networking.wireless.enable = true;  # Enables wireless support via wpa_supplicant.

  # Configure network proxy if necessary
  # networking.proxy.default = "http://user:password@proxy:port/";
  # networking.proxy.noProxy = "127.0.0.1,localhost,internal.domain";

  # Enable networking
  networking.networkmanager.enable = true;

  # Set your time zone.
  time.timeZone = "Europe/Berlin";

  # Select internationalisation properties.
  i18n.defaultLocale = "de_DE.UTF-8";

  i18n.extraLocaleSettings = {
    LC_ADDRESS = "de_DE.UTF-8";
    LC_IDENTIFICATION = "de_DE.UTF-8";
    LC_MEASUREMENT = "de_DE.UTF-8";
    LC_MONETARY = "de_DE.UTF-8";
    LC_NAME = "de_DE.UTF-8";
    LC_NUMERIC = "de_DE.UTF-8";
    LC_PAPER = "de_DE.UTF-8";
    LC_TELEPHONE = "de_DE.UTF-8";
    LC_TIME = "de_DE.UTF-8";
  };

  # Enable the X11 windowing system.
  services.xserver.enable = true;

  # Enable the GNOME Desktop Environment.
  services.xserver.displayManager.gdm.enable = true;
  services.xserver.desktopManager.gnome.enable = true;

  # Configure keymap in X11
  services.xserver.xkb = {
    layout = "de";
    variant = "";
  };

  # Configure console keymap
  console.keyMap = "de";

  # Enable CUPS to print documents.
  services.printing.enable = false;

  # Enable sound with pipewire.
  hardware.pulseaudio.enable = false;
  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    alsa.support32Bit = true;
    pulse.enable = true;
    # If you want to use JACK applications, uncomment this
    #jack.enable = true;

    # use the example session manager (no others are packaged yet so this is enabled by default,
    # no need to redefine it in your config for now)
    #media-session.enable = true;
  };

  # Enable touchpad support (enabled default in most desktopManager).
  # services.xserver.libinput.enable = true;

  # Define a user account. Don't forget to set a password with ‘passwd’.
  users.users.pika = {
    isNormalUser = true;
    description = "pika";
    extraGroups = [ "networkmanager" "docker" "wheel" ];
    packages = with pkgs; [
    # ─< utility packages (cli) >─────────────────────────────────────────────────────────────
      fastfetch
      fzf
      git
      neovim
      oh-my-posh
      tldr
      wl-clipboard-rs # rust version of wl-clipboard
      yazi

    # ─< qol eye candy (wayland) >────────────────────────────────────────────────────────────
      gbar
      neovide
      nwg-look
      rofi-wayland
      wlogout
      waybar
      swww

    # ─< terminals >──────────────────────────────────────────────────────────────────────────
      ghostty
      kitty

    # ─────────────────────────────────< windowmanager stuff >───────────────────────────────
      copyq

    # ─< graphical filemanager >──────────────────────────────────────────────────────────────
      mate.caja
      mate.caja-extensions

    # ─< browser >────────────────────────────────────────────────────────────────────────────
      floorp
    ];
  };

  # Install firefox.
  # programs.firefox.enable = true;
  programs.hyprland.enable = true; # enable Hyprland

  # Allow unfree packages
  nixpkgs.config.allowUnfree = true;
  virtualisation.docker.enable = true;

  # List packages installed in system profile. To search, run:
  # $ nix search wget
  environment.systemPackages = with pkgs; [
  #  vim # Do not forget to add an editor to edit configuration.nix! The Nano editor is also installed by default.
  swaynotificationcenter
  
# ────────────────────────────────────────< system >────────────────────────────────────────
  libnotify
  libgcc
  unzip
  zip
  wget
  curl
  gnumake
  stow
  trash-cli

# ─────────────────────────────────────────< qol >───────────────────────────────────────
  tmux
  zoxide
  rsync
  eza
  zsh

  zig

# ────────────────────────────────────────< docker >────────────────────────────────────────
  docker
  docker-compose
  lazydocker

# ─< hyprland stuff >─────────────────────────────────────────────────────────────────────
  xdg-desktop-portal-hyprland

  # hyprpanel
  ladybird
  ];

  # Some programs need SUID wrappers, can be configured further or are
  # started in user sessions.
  # programs.mtr.enable = true;
  # programs.gnupg.agent = {
  #   enable = true;
  #   enableSSHSupport = true;
  # };

  # List services that you want to enable:

  # Enable the OpenSSH daemon.
  # services.openssh.enable = true;

  # Open ports in the firewall.
  # networking.firewall.allowedTCPPorts = [ ... ];
  # networking.firewall.allowedUDPPorts = [ ... ];
  # Or disable the firewall altogether.
  # networking.firewall.enable = false;

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "24.11"; # Did you read the comment?

}
